# Script tests
To regenerate all of the tests from scratch, remove the `test_scripts/output` directory.  All of the
test cases will then be regenerated.  You can also remove individual files as needed.